Icons - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

### Tabler Icons

All icons come from the Tabler Icons set and are MIT-licensed. Visit tabler-icons.io, download any of the 1518 icons in SVG, PNG or React and use them in your favourite design tools.
Download icons

# Icons

Use one of over 1500 icons created specifically for Tabler and make your dashboard look even more attractive. All icons are under MIT license, so you can use them without any problem both in private and commercial projects.

## Base icon

    <!-- Download SVG icon from http://tabler-icons.io/i/heart -->
    <!-- SVG icon code -->
    <!-- Download SVG icon from http://tabler-icons.io/i/ghost -->
    <!-- SVG icon code -->
    <!-- Download SVG icon from http://tabler-icons.io/i/star -->
    <!-- SVG icon code -->
    <!-- Download SVG icon from http://tabler-icons.io/i/bike -->
    <!-- SVG icon code -->

## Filled icons

    <!-- Download SVG icon from http://tabler-icons.io/i/heart -->
    <!-- SVG icon code with class="icon-filled" -->
    <!-- Download SVG icon from http://tabler-icons.io/i/circle -->
    <!-- SVG icon code with class="icon-filled" -->
    <!-- Download SVG icon from http://tabler-icons.io/i/star -->
    <!-- SVG icon code with class="icon-filled" -->
    <!-- Download SVG icon from http://tabler-icons.io/i/square -->
    <!-- SVG icon code with class="icon-filled" -->

## Icon colors

    <span class="text-red">
      <!-- Download SVG icon from http://tabler-icons.io/i/heart -->
      <!-- SVG icon code with class="icon-filled" -->
    </span>
    <span class="text-yellow">
      <!-- Download SVG icon from http://tabler-icons.io/i/star -->
      <!-- SVG icon code with class="icon-filled" -->
    </span>
    <span class="text-blue">
      <!-- Download SVG icon from http://tabler-icons.io/i/circle -->
      <!-- SVG icon code -->
    </span>
    <span class="text-green">
      <!-- Download SVG icon from http://tabler-icons.io/i/square -->
      <!-- SVG icon code -->
    </span>